{% extends "sphinx_rtd_theme/footer.html" %}

{#
  The design of the rtd-theme footer template includes content which is
  not inside a block (and thus not trivial to overwrite). By setting
  the following variabels we essentially hide footer content which we want
  to include ourselves. P.S. These variables are only used in the footer.
#}
{% set show_sphinx = false %}
{% set show_copyright = false %}

{#
  Footer design largely replicates https://github.com/nextstrain/nextstrain.org/raw/0c3222d/static-site/src/components/Footer/index.jsx
#}

{#
  The following could probably be written in a much nicer, less verbose style.
  This is/was my first time using Jinja, so i'm falling back onto basic HTML.
  If you can improve this, please do & show me the way!       james oct 2020
#}
{% block extrafooter %}

  <div class="citation">
    Hadfield <i>et al.,</i>
    <a href="https://doi.org/10.1093/bioinformatics/bty407">Nextstrain: real-time tracking of pathogen evolution</a>
    <i>, Bioinformatics</i> (2018)
  </def>


  <p class="avatar">Nextstrain is built by</p>
  <div class="avatar">
    {% macro TeamMember(name, image, link) %}
    <span>
      {% if link %}<a href="{{ link |e }}">{% endif %}
        <img src="{{ pathto('_static/team/' + image, 1) }}" width="32"/>
        {{ name |e }}
      {% if link %}</a>{% endif %}
    </span>
    {% endmacro %}
    {{ TeamMember(name="Trevor Bedford", image="trevor-bedford.jpg", link="http://bedford.io/team/trevor-bedford/") }},
    {{ TeamMember(name="Richard Neher", image="richard-neher.jpg", link="https://neherlab.org/richard-neher.html") }},
    {{ TeamMember(name="James Hadfield", image="james-hadfield.jpg", link="http://bedford.io/team/james-hadfield/") }},
    {{ TeamMember(name="Emma Hodcroft", image="emma-hodcroft.jpg", link="http://emmahodcroft.com/") }},
    {{ TeamMember(name="Thomas Sibley", image="thomas-sibley.jpg", link="https://bedford.io/team/thomas-sibley/") }},
    {{ TeamMember(name="John Huddleston", image="john-huddleston.jpg", link="http://bedford.io/team/john-huddleston/") }},
    {{ TeamMember(name="Ivan Aksamentov", image="ivan-aksamentov.jpg", link="https://neherlab.org/ivan-aksamentov.html") }},
    {{ TeamMember(name="Jover Lee", image="jover-lee.jpg", link="http://bedford.io/team/jover-lee/") }},
    {{ TeamMember(name="Kairsten Fay", image="kairsten-fay.jpg", link="http://bedford.io/team/kairsten-fay/") }},
    {{ TeamMember(name="Moira Zuber", image="moira-zuber.jpg") }},
    {{ TeamMember(name="Eli Harkins", image="eli-harkins.jpg", link="https://bedford.io/team/eli-harkins/") }},
    {{ TeamMember(name="Misja Ilcisin", image="misja-ilcisin.jpg", link="http://bedford.io/team/misja-ilcisin/") }},
    {{ TeamMember(name="Cassia Wagner", image="cassia-wagner.jpg", link="https://bedford.io/team/cassia-wagner/") }},
    {{ TeamMember(name="Louise Moncla", image="louise-moncla.jpg", link="http://bedford.io/team/louise-moncla/") }},
    {{ TeamMember(name="Allison Black", image="allison-black.jpg", link="http://bedford.io/team/allison-black/") }},
    {{ TeamMember(name="Sidney Bell", image="sidney-bell.jpg", link="http://bedford.io/team/sidney-bell/") }},
    {{ TeamMember(name="Miguel Parades", image="miguel-parades.jpg", link="https://bedford.io/team/miguel-parades/") }},
    {{ TeamMember(name="Colin Megill", image="colin-megill.jpg", link="http://www.colinmegill.com/") }},
    {{ TeamMember(name="Barney Potter", image="barney-potter.jpg", link="http://bedford.io/team/barney-potter/") }},
    {{ TeamMember(name="Pavel Sagulenko", image="pavel-sagulenko.jpg", link="https://neherlab.org/pavel-sagulenko.html") }},
    {{ TeamMember(name="Charlton Callender", image="charlton-callender.jpg", link="http://bedford.io/team/charlton-callender/") }}
  </div>


  <div class="footer-small-text">
    All <a href="https://github.com/nextstrain">source code for Nextstrain</a> is freely available under the terms of an <a href="https://opensource.org/osd">open-source license</a>, typically <a href="https://opensource.org/licenses/AGPL-3.0">AGPL-3.0</a> or <a href="https://opensource.org/licenses/MIT">MIT</a>.
    Refer to specific projects for details.
    Screenshots may be used under a <a href="https://creativecommons.org/licenses/by/4.0/">CC-BY-4.0 license</a> and attribution to nextstrain.org must be provided.
  </div>

  <div class="footer-small-text">
    This work is made possible by the open sharing of genetic data by research groups from all over the world.
    We gratefully acknowledge their contributions.
    Special thanks to Kristian Andersen, Josh Batson, David Blazes, Jesse Bloom, Peter Bogner, Anderson Brito, Matt Cotten, Ana Crisan, Tulio de Oliveira, Gytis Dudas, Vivien Dugan, Karl Erlandson, Nuno Faria, Jennifer Gardy, Nate Grubaugh, Becky Kondor, Dylan George, Ian Goodfellow, Betz Halloran, Christian Happi, Jeff Joy, Paul Kellam, Philippe Lemey, Nick Loman, Duncan MacCannell, Erick Matsen, Sebastian Maurer-Stroh, Placide Mbala, Danny Park, Oliver Pybus, Andrew Rambaut, Colin Russell, Pardis Sabeti, Katherine Siddle, Kristof Theys, Dave Wentworth, Shirlee Wohl and Cecile Viboud for comments, suggestions and data sharing.
  </div>

  <hr/>

  <div class="logo">
    <a class="logo" href="http://www.fredhutch.org/">
      <span class="logo"></span>
      <img alt="Logo of the Fred Hutch" style="width:90px; max-width:90px;" src="{{ pathto('_static/logos/fred-hutch-logo-small.png', 1) }}" />
    </a>
    <a class="logo" href="http://www.sib.swiss/">
      <span class="logo"></span>
      <img alt="Logo of the Swiss Institute of Bioinformatics" style="width:90px; max-width:90px;" src="{{ pathto('_static/logos/sib-logo.png', 1) }}"/>
    </a>
    <a class="logo" href="https://www.nih.gov/">
      <span class="logo"></span>
      <img alt="Logo of the National Institutes of Health" style="width:65px; max-width:65px;" src="{{ pathto('_static/logos/nih-logo.jpg', 1) }}"/>
    </a>
    <a class="logo" href="https://www.mapbox.com">
      <span class="logo"></span>
      <img alt="Logo of Mapbox" style="width:115px; max-width:115px;" src="{{ pathto('_static/logos/mapbox-logo-black.svg', 1) }}"/>
    </a>
    <a class="logo" href="https://unibas.ch/">
      <span class="logo"></span>
      <img alt="Logo of the University of Basel" style="width:110px; max-width:110px;" src="{{ pathto('_static/logos/unibas-logo.svg', 1) }}"/>
    </a>
    <a class="logo" href="https://www.nih.gov/news-events/news-releases/open-science-prize-announces-epidemic-tracking-tool-grand-prize-winner">
      <span class="logo"></span>
      <img alt="Logo of the Open Science Prize" style="width:110px; max-width:110px;" src="{{ pathto('_static/logos/osp-logo-small.png', 1) }}"/>
    </a>
    <a class="logo" href="http://biozentrum.org/">
      <span class="logo"></span>
      <img alt="Logo of the Biozentrum" style="width:115px; max-width:115px;" src="{{ pathto('_static/logos/bz_logo.png', 1) }}"/>
    </a>
  </div>

  <div class="copyright">
    &copy; {% trans %}Copyright{% endtrans %} {{ copyright }}
  </div>

  <div class="copyright">
    {%- if build_id and build_url %}
      Build <a href="{{ build_url }}">{{ build_id }}</a>.
    {%- elif commit %}
      Revision <code>{{ commit }}</code>.
    {%- endif %}
    {%- if last_updated %}
      Last updated on {{ last_updated }}.
    {%- endif %}
    </p>
    Built with <a href="https://www.sphinx-doc.org/">Sphinx</a>
    using <a href="https://github.com/nextstrain/sphinx-theme">our customised version</a> of a
    <a href="https://github.com/readthedocs/sphinx_rtd_theme">base theme</a> provided by
    <a href="https://readthedocs.org">Read the Docs</a>.
  </div>

{% endblock %}
